==> aksharamukha-1.0.12.tar.gz: aksharamukha-1.0.12/aksharamukha/ScriptMap/Roman/SoraSompeng.py <==
# -*- coding: utf-8 -*-

# Script Mapping for ISO

VowelMap =  [
            'ə',
            '\U000110E2',
            '\U000110E4',
            '\U000110E4\u02BD',
            '\U000110E5',
            '\U000110E5\u02BD',
            '\U000110DD\U000110E4\u02BD',
            '\U000110DD\U000110E4\u02BD',
            '\U000110D8\U000110E4\u02BD',
            '\U000110D8\U000110E4\u02BD',
            '\U000110E3',
            '\U000110E7',
            '\U000110E6',
            '\U000110E6\U000110E5'
            ]

SouthVowelMap = [
                '\U000110E3\u02BD',
                '\U000110E6\u02BD',
                ]

ModernVowelMap = [
                '\U000110E3\u02BD',
                 '\U000110E2\u02BD',
                 ]

SinhalaVowelMap = [
                '\U000110E3\u02BD',
                  ]

VowelSignMap =  VowelMap[1:]

SouthVowelSignMap = SouthVowelMap[:]

ModernVowelSignMap = ModernVowelMap[:]

SinhalaVowelSignMap = SinhalaVowelMap[:]

AyogavahaMap = [
               '\U000110D6\u02BD',
               '\U000110D6\u02BD',
               '\U000110DE\u02BD'
               ]

ViramaMap =  [
             '\u00D7'
             ]

### JA or YA for aspiration
### I have used JA for now.

ConsonantMap =  [
                '\U000110DF',
                '\U000110DF\U000110E0',
                '\U000110D5',
                '\U000110D5\U000110E0',
                '\U000110D7',

                '\U000110D3',
                '\U000110D3\U000110E0',
                '\U000110E0',
                '\U000110E0\U000110E0',
                '\U000110E1',

                '\U000110D1\U000110E8',
                '\U000110D1\U000110E8\U000110E0',
                '\U000110D4',
                '\U000110D4\U000110E0',
                '\U000110D9\U000110E8',

                '\U000110D1',
                '\U000110D1\U000110E0',
                '\U000110D4\u02BD',
                '\U000110D4\U000110E0\u02BD',
                '\U000110D9',

                '\U000110DB',
                '\U000110DB\U000110E0',
                '\U000110D2',
                '\U000110D2\U000110E0',
                '\U000110D6',

                '\U000110DC',
                '\U000110DD',
                '\U000110D8',
                '\U000110DA',

                '\U000110D0\U000110E0\u02BD',
                '\U000110D0\U000110E8',
                '\U000110D0',
                '\U000110DE',
                ]

SouthConsonantMap = [
                    '\U000110D8\U000110E8',
                    '\U000110D8\U000110E8\u02BD',
                    '\U000110D8\u02BD',
                    '\U000110D9\u02BD'
                    ]

NuktaConsonantMap =  [
                     '\U000110DF\u02BD',
                     '\U000110DF\U000110E0\u02BD',
                     '\U000110D5\u02BD',
                     '\U000110E0\u02BD',
                     '\U000110DD\U000110D4',
                     '\U000110DD\U000110D4\U000110E0',
                     '\U000110DB\U000110E0\u02BD',
                     '\U000110DC\u02BD'
                     ]

SinhalaConsonantMap =[
                     '\U000110D7\U000110D5\u02BD',
                     '\U000110E1\U000110D3\u02BD',
                     '\U000110D9\U000110E8\U000110D4\u02BD',
                     '\U000110D9\U000110D4\u02BD',
                     '\U000110D6\U000110DB\u02BD',
                      ]

NuktaMap = [
           '\U000110E8\u02BD'
           ]

OmMap = [
        '\U000110E6\U000110D6\u02BD'
        ]

SignMap =[
         '\u0027',
         '.',
         '..'
         ]

Aytham =['\U000110DE\u02BD']

NumeralMap = [
             '\U000110F0',
             '\U000110F1',
             '\U000110F2',
             '\U000110F3',
             '\U000110F4',
             '\U000110F5',
             '\U000110F6',
             '\U000110F7',
             '\U000110F8',
             '\U000110F9',
             ]

==> aksharamukha-2.0.2.tar.gz: aksharamukha-2.0.2/aksharamukha/ScriptMap/Roman/SoraSompeng.py <==
# -*- coding: utf-8 -*-

# Script Mapping for ISO

VowelMap =  [
            'ə',
            '\U000110E2',
            '\U000110E4',
            '\U000110E4\u02BD',
            '\U000110E5',
            '\U000110E5\u02BD',
            '\U000110DD\U000110E4\u02BD',
            '\U000110DD\U000110E4\u02BD',
            '\U000110D8\U000110E4\u02BD',
            '\U000110D8\U000110E4\u02BD',
            '\U000110E3',
            '\U000110E7',
            '\U000110E6',
            '\U000110E6\U000110E5'
            ]

SouthVowelMap = [
                '\U000110E3\u02BD',
                '\U000110E6\u02BD',
                ]

ModernVowelMap = [
                '\U000110E3\u02BD',
                 '\U000110E2\u02BD',
                 ]

SinhalaVowelMap = [
                '\U000110E3\u02BD',
                  ]

VowelSignMap =  VowelMap[1:]

SouthVowelSignMap = SouthVowelMap[:]

ModernVowelSignMap = ModernVowelMap[:]

SinhalaVowelSignMap = SinhalaVowelMap[:]

AyogavahaMap = [
               '\U000110D6\u02BD',
               '\U000110D6\u02BD',
               '\U000110DE\u02BD'
               ]

ViramaMap =  [
             '\u00D7'
             ]

### JA or YA for aspiration
### I have used JA for now.

ConsonantMap =  [
                '\U000110DF',
                '\U000110DF\U000110E0',
                '\U000110D5',
                '\U000110D5\U000110E0',
                '\U000110D7',

                '\U000110D3',
                '\U000110D3\U000110E0',
                '\U000110E0',
                '\U000110E0\U000110E0',
                '\U000110E1',

                '\U000110D1\U000110E8',
                '\U000110D1\U000110E8\U000110E0',
                '\U000110D4',
                '\U000110D4\U000110E0',
                '\U000110D9\U000110E8',

                '\U000110D1',
                '\U000110D1\U000110E0',
                '\U000110D4\U000110E8',
                '\U000110D4\U000110E8\U000110E0\u02BD',
                '\U000110D9',

                '\U000110DB',
                '\U000110DB\U000110E0',
                '\U000110D2',
                '\U000110D2\U000110E0',
                '\U000110D6',

                '\U000110DC',
                '\U000110DD',
                '\U000110D8',
                '\U000110DA',

                '\U000110D0\U000110E0\u02BD',
                '\U000110D0\U000110E8',
                '\U000110D0',
                '\U000110DE',
                ]

SouthConsonantMap = [
                    '\U000110D8\U000110E8',
                    '\U000110D8\U000110E8\u02BD',
                    '\U000110D8\u02BD',
                    '\U000110D9\u02BD'
                    ]

NuktaConsonantMap =  [
                     '\U000110DF\u02BD',
                     '\U000110DF\U000110E0\u02BD',
                     '\U000110D5\u02BD',
                     '\U000110E0\u02BD',
                     '\U000110DD\U000110D4',
                     '\U000110DD\U000110D4\U000110E0',
                     '\U000110DB\U000110E0\u02BD',
                     '\U000110DC\u02BD'
                     ]

SinhalaConsonantMap =[
                     '\U000110D7\U000110D5\u02BD',
                     '\U000110E1\U000110D3\u02BD',
                     '\U000110D9\U000110E8\U000110D4\u02BD',
                     '\U000110D9\U000110D4\u02BD',
                     '\U000110D6\U000110DB\u02BD',
                      ]

NuktaMap = [
           '\U000110E8\u02BD'
           ]

OmMap = [
        '\U000110E6\U000110D6\u02BD'
        ]

SignMap =[
         '\u0027',
         '.',
         '..'
         ]

Aytham =['\U000110DE\u02BD']

NumeralMap = [
             '\U000110F0',
             '\U000110F1',
             '\U000110F2',
             '\U000110F3',
             '\U000110F4',
             '\U000110F5',
             '\U000110F6',
             '\U000110F7',
             '\U000110F8',
             '\U000110F9',
             ]
